@@ -19,17 +19,17 @@
 
 /**
  * SECTION:element-amrnbdec
+ * @title: amrnbdec
  * @see_also: #GstAmrnbEnc, #GstAmrParse
  *
- * AMR narrowband decoder based on the 
- * <ulink url="http://sourceforge.net/projects/opencore-amr">opencore codec implementation</ulink>.
- * 
- * <refsect2>
- * <title>Example launch line</title>
+ * AMR narrowband decoder based on the
+ * [opencore codec implementation](http://sourceforge.net/projects/opencore-amr).
+ *
+ * ## Example launch line
  * |[
  * gst-launch-1.0 filesrc location=abc.amr ! amrparse ! amrnbdec ! audioconvert ! audioresample ! autoaudiosink
  * ]|
- * </refsect2>
+ *
  */
 
 #ifdef HAVE_CONFIG_H
@@ -96,8 +96,8 @@ static void gst_amrnbdec_get_property (GObject * object, guint prop_id,
 static gboolean gst_amrnbdec_start (GstAudioDecoder * dec);
 static gboolean gst_amrnbdec_stop (GstAudioDecoder * dec);
 static gboolean gst_amrnbdec_set_format (GstAudioDecoder * dec, GstCaps * caps);
-static gboolean gst_amrnbdec_parse (GstAudioDecoder * dec, GstAdapter * adapter,
-    gint * offset, gint * length);
+static GstFlowReturn gst_amrnbdec_parse (GstAudioDecoder * dec,
+    GstAdapter * adapter, gint * offset, gint * length);
 static GstFlowReturn gst_amrnbdec_handle_frame (GstAudioDecoder * dec,
     GstBuffer * buffer);
 
@@ -114,10 +114,8 @@ gst_amrnbdec_class_init (GstAmrnbDecClass * klass)
   object_class->set_property = gst_amrnbdec_set_property;
   object_class->get_property = gst_amrnbdec_get_property;
 
-  gst_element_class_add_pad_template (element_class,
-      gst_static_pad_template_get (&sink_template));
-  gst_element_class_add_pad_template (element_class,
-      gst_static_pad_template_get (&src_template));
+  gst_element_class_add_static_pad_template (element_class, &sink_template);
+  gst_element_class_add_static_pad_template (element_class, &src_template);
 
   gst_element_class_set_static_metadata (element_class, "AMR-NB audio decoder",
       "Codec/Decoder/Audio",
@@ -138,6 +136,8 @@ gst_amrnbdec_class_init (GstAmrnbDecClass * klass)
 
   GST_DEBUG_CATEGORY_INIT (gst_amrnbdec_debug, "amrnbdec", 0,
       "AMR-NB audio decoder");
+
+  gst_type_mark_as_plugin_api (GST_AMRNB_VARIANT_TYPE, 0);
 }
 
 static void
@@ -243,14 +243,12 @@ gst_amrnbdec_parse (GstAudioDecoder * dec, GstAdapter * adapter,
   gint block, mode;
 
   size = gst_adapter_available (adapter);
-  g_return_val_if_fail (size > 0, GST_FLOW_ERROR);
+  if (size < 1)
+    return GST_FLOW_ERROR;
 
   gst_audio_decoder_get_parse_state (dec, &sync, &eos);
 
   /* need to peek data to get the size */
-  if (size < 1)
-    return GST_FLOW_ERROR;
-
   gst_adapter_copy (adapter, head, 0, 1);
 
   /* get size */
