@@ -72,10 +72,8 @@ gst_dvd_sub_parse_class_init (GstDvdSubParseClass * klass)
   gstelement_class->change_state =
       GST_DEBUG_FUNCPTR (gst_dvd_sub_parse_change_state);
 
-  gst_element_class_add_pad_template (gstelement_class,
-      gst_static_pad_template_get (&src_template));
-  gst_element_class_add_pad_template (gstelement_class,
-      gst_static_pad_template_get (&sink_template));
+  gst_element_class_add_static_pad_template (gstelement_class, &src_template);
+  gst_element_class_add_static_pad_template (gstelement_class, &sink_template);
 
   gst_element_class_set_static_metadata (gstelement_class,
       "DVD subtitle parser", "Codec/Parser/Subtitle",
